@@ -5,6 +5,7 @@ import numpy             as np
 import nibabel           as nib
 import scipy.io          as sio
 import matplotlib.pyplot as plt
+from bids.layout  import BIDSLayout, parse_file_entities 
 from scipy        import stats, signal
 from scipy.sparse import lil_matrix
 from rsHRF        import spm_dep, processing, parameters, basis_functions, utils, iterative_wiener_deconv
@@ -25,15 +26,15 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
     # for four-dimensional input
     if mode != 'time-series':
         if mode == 'bids' or mode == 'bids w/ atlas':
-            name = input_file.filename.split('/')[-1].split('.')[0]
-            v1 = spm_dep.spm.spm_vol(input_file.filename)
-        else:
             name = input_file.split('/')[-1].split('.')[0]
             v1 = spm_dep.spm.spm_vol(input_file)
+        else:
+            name = input_file.split('/')[-1].split('.')[0]   
+            v1 = spm_dep.spm.spm_vol(input_file)
         if mask_file != None:
             if mode == 'bids':
-                mask_name = mask_file.filename.split('/')[-1].split('.')[0]
-                v = spm_dep.spm.spm_vol(mask_file.filename)
+                mask_name = mask_file.split('/')[-1].split('.')[0]
+                v = spm_dep.spm.spm_vol(mask_file)
             else:
                 mask_name = mask_file.split('/')[-1].split('.')[0]
                 v = spm_dep.spm.spm_vol(mask_file)
@@ -48,17 +49,17 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
                 raise ValueError ('Inconsistency in input-mask dimensions' + '\n\tinput_file == ' + name + file_type + '\n\tmask_file == ' + mask_name + file_type)
             else:
                 if file_type == ".nii" or file_type == ".nii.gz" :
-                    data   = v1.get_data()
+                    data   = v1.get_data()      
                 else:
                     data   = v1.agg_data()
         else:
             print('No atlas provided! Generating mask file...')
             if file_type == ".nii" or file_type == ".nii.gz" :
-                data   = v1.get_data()
+                data   = v1.get_data() 
                 brain  = np.nanvar(data.reshape(-1, data.shape[3]), -1, ddof=0)
             else:
                 data   = v1.agg_data()
-                brain  = np.nanvar(data, -1, ddof=0)
+                brain  = np.nanvar(data, -1, ddof=0) 
             print('Done')
         voxel_ind  = np.where(brain > 0)[0]
         mask_shape = data.shape[:-1]
@@ -78,10 +79,10 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
     bold_sig = np.nan_to_num(bold_sig)
     bold_sig_deconv = processing. \
                       rest_filter. \
-                      rest_IdealFilter(bold_sig, para['TR'], para['passband_deconvolve'])
+                      rest_IdealFilter(bold_sig, para['TR'], para['passband_deconvolve'])   
     bold_sig = processing. \
                rest_filter. \
-               rest_IdealFilter(bold_sig, para['TR'], para['passband'])
+               rest_IdealFilter(bold_sig, para['TR'], para['passband'])   
     data_deconv  = np.zeros(bold_sig.shape)
     event_number = np.zeros((1, bold_sig.shape[1]))
     print('Retrieving HRF ...')
@@ -92,6 +93,7 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
         hrfa = np.dot(bf, beta_hrf[np.arange(0, bf.shape[1]), :])
     #Estimate HRF for FIR and sFIR
     else:
+        para['T'] = 1        
         beta_hrf, event_bold = utils.hrf_estimation.compute_hrf(bold_sig, para, temporal_mask, p_jobs)
         hrfa = beta_hrf[:-1,:]
     nvar = hrfa.shape[1]
@@ -118,19 +120,13 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
         else:
             data_deconv[:, voxel_id] = iterative_wiener_deconv.rsHRF_iterative_wiener_deconv(bold_sig_deconv[:, voxel_id], hrf)
         event_number[:, voxel_id] = np.amax(event_bold[voxel_id].shape)
+    print('Done')
+    print('Saving Output ...')
     # setting the output-path
     if mode == 'bids' or mode == 'bids w/ atlas':
-        try:
-            sub_save_dir = os.path.join(
-                output_dir, 'sub-' + input_file.subject,
-                'session-' + input_file.session,
-                input_file.modality
-            )
-        except AttributeError as e:
-            sub_save_dir = os.path.join(
-                output_dir, 'sub-' + input_file.subject,
-                input_file.modality
-            )
+        layout_output = BIDSLayout(output_dir)
+        entities = parse_file_entities(input_file)
+        sub_save_dir = layout_output.build_path(entities).rsplit('/',1)[0]            
     else:
         sub_save_dir = output_dir
     if not os.path.isdir(sub_save_dir):
@@ -141,8 +137,9 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
         dic["event_number"] = event_number
         dic["data_deconv"]  = data_deconv
         ext = '_hrf_deconv.mat'
+    name = name.rsplit('_bold', 1)[0]   
     sio.savemat(os.path.join(sub_save_dir, name + ext), dic)
-    HRF_para_str = ['Height', 'Time2peak', 'FWHM']
+    HRF_para_str = ['height', 'T2P', 'FWHM']
     if mode != "time-series":
         mask_data = np.zeros(mask_shape).flatten(order='F')
         for i in range(3):
@@ -152,7 +149,7 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
             mask_data = mask_data.reshape(mask_shape, order='F')
             spm_dep.spm.spm_write_vol(v1, mask_data, fname, file_type)
             mask_data = mask_data.flatten(order='F')
-        fname = os.path.join(sub_save_dir, name + '_event_number.nii')
+        fname = os.path.join(sub_save_dir, name + '_eventnumber')
         mask_data[voxel_ind] = event_number
         mask_data = mask_data.reshape(mask_shape, order='F')
         spm_dep.spm.spm_write_vol(v1, mask_data, fname, file_type)
@@ -171,7 +168,7 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
     pos = 0
     while pos < hrfa_TR.shape[1]:
         if np.any(hrfa_TR[:,pos]):
-            break
+            break 
         pos += 1
     event_plot = lil_matrix((1, nobs))
     if event_bold.size:
@@ -184,7 +181,7 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
     plt.plot(para['TR'] * np.arange(1, np.amax(hrfa_TR[:, pos].shape) + 1),
              hrfa_TR[:, pos], linewidth=1)
     plt.xlabel('time (s)')
-    plt.savefig(os.path.join(sub_save_dir, name + '_plot_1.png'))
+    plt.savefig(os.path.join(sub_save_dir, name + '_hrf_plot.png'))
     plt.figure()
     plt.plot(para['TR'] * np.arange(1, nobs + 1),
              np.nan_to_num(stats.zscore(bold_sig[:, pos], ddof=1)),
@@ -197,8 +194,8 @@ def demo_rsHRF(input_file, mask_file, output_dir, para, p_jobs, file_type=".nii"
     plt.setp(baseline, 'color', 'k', 'markersize', 1)
     plt.setp(stemlines, 'color', 'k')
     plt.setp(markerline, 'color', 'k', 'markersize', 3, 'marker', 'd')
-    plt.legend(['BOLD', 'deconvolved', 'events'])
+    plt.legend(['BOLD', 'Deconvolved BOLD', 'Events'], loc='best')
     plt.xlabel('time (s)')
-    plt.savefig(os.path.join(sub_save_dir, name + '_plot_2.png'))
+    plt.savefig(os.path.join(sub_save_dir, name + '_deconvolution_plot.png'))   
     print('Done')
     return 0
